==> v1.2.3.zip: syncthingtray/plasmoid/translations/syncthingplasmoid_en_US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>DetailView</name>
    <message>
        <location filename="../package/contents/ui/DetailView.qml" line="14"/>
        <source>Copy value</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DevicesPage</name>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="64"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="64"/>
        <location filename="../package/contents/ui/DevicesPage.qml" line="116"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="102"/>
        <source>Copy name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="107"/>
        <source>Copy ID</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DirectoriesPage</name>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="23"/>
        <source>Filter directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="84"/>
        <source>Show errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="95"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="164"/>
        <source>Rescan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="103"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="103"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="171"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="113"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="178"/>
        <source>Open in file browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="150"/>
        <source>Copy label/ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="155"/>
        <source>Copy path</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadsPage</name>
    <message>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="66"/>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="122"/>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="147"/>
        <source>Open in file browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="138"/>
        <source>Copy label/ID</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FullRepresentation</name>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="246"/>
        <source>Global</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="253"/>
        <source>Global incoming traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="271"/>
        <source>Local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="278"/>
        <source>Global outgoing traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="33"/>
        <source>Directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="39"/>
        <source>Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="45"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="51"/>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="104"/>
        <source>Toggle filter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plasmoid::AppearanceOptionPage</name>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="6"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="25"/>
        <source>Size of directory/device/download list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="64"/>
        <source> x </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="90"/>
        <source> grid units</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="108"/>
        <source>Note that the size is ignored when the Plasmoid is displayed on the desktop or in full screen mode. When displayed as entry of the system tray Plasmoid the size can not be changed (setting a high value just leads to the contents being clipped).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="120"/>
        <source>States to enable passive mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="140"/>
        <source>Optional GUI elements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="147"/>
        <source>Show tab texts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plasmoid::Settings</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="29"/>
        <source>The settings on this page are specific to the current instance of the Plasmoid.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plasmoid::SettingsDialog</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="126"/>
        <source>Plasmoid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="134"/>
        <source>Web view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="140"/>
        <source>Extras</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plasmoid::ShortcutOptionPage</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="66"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="72"/>
        <source>Global shortcut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plasmoid::SyncthingApplet</name>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="380"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="392"/>
        <source>New notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="550"/>
        <source>D-Bus error - unable to </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecentChangesPage</name>
    <message>
        <location filename="../package/contents/ui/RecentChangesPage.qml" line="109"/>
        <source>Copy path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/RecentChangesPage.qml" line="114"/>
        <source>Copy device ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/RecentChangesPage.qml" line="119"/>
        <source>Copy directory ID</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatisticsView</name>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="12"/>
        <source> files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="17"/>
        <source> directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="23"/>
        <source> size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToolBar</name>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="25"/>
        <source>Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="41"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="50"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="99"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="113"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="169"/>
        <source>Show new notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="188"/>
        <source>About Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="200"/>
        <source>Show own device ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="216"/>
        <source>Show Syncthing log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="228"/>
        <source>Rescan all directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="244"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="259"/>
        <source>Open Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../package/contents/ui/main.qml" line="59"/>
        <source>Open Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="60"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="61"/>
        <source>Rescan all directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="63"/>
        <source>Show own device ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="65"/>
        <source>Restart Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="67"/>
        <source>Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="68"/>
        <source>Internal errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="70"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> v1.4.3.zip: syncthingtray/plasmoid/translations/syncthingplasmoid_en_US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>DetailView</name>
    <message>
        <location filename="../package/contents/ui/DetailView.qml" line="14"/>
        <source>Copy value</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DevicesPage</name>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="64"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="64"/>
        <location filename="../package/contents/ui/DevicesPage.qml" line="116"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="102"/>
        <source>Copy name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="107"/>
        <source>Copy ID</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DirectoriesPage</name>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="23"/>
        <source>Filter directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="84"/>
        <source>Show errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="95"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="164"/>
        <source>Rescan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="103"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="103"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="171"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="113"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="178"/>
        <source>Open in file browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="150"/>
        <source>Copy label/ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="155"/>
        <source>Copy path</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadsPage</name>
    <message>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="66"/>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="122"/>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="147"/>
        <source>Open in file browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="138"/>
        <source>Copy label/ID</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FullRepresentation</name>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="246"/>
        <source>Global</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="253"/>
        <source>Global incoming traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="271"/>
        <source>Local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="278"/>
        <source>Global outgoing traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="33"/>
        <source>Directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="39"/>
        <source>Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="45"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="51"/>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="104"/>
        <source>Toggle filter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plasmoid::AppearanceOptionPage</name>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="6"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="25"/>
        <source>Size of directory/device/download list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="64"/>
        <source> x </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="90"/>
        <source> grid units</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="108"/>
        <source>Note that the size is ignored when the Plasmoid is displayed on the desktop, in full screen mode or as entry of the system tray Plasmoid. Then the Plasmoid can be resized using Plasma&apos;s UI. On Plasma older than 5.26, when displayed as entry of the system tray Plasmoid the size can not be changed (setting a high value just leads to the contents being clipped).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="120"/>
        <source>States to enable passive mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="140"/>
        <source>Optional GUI elements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="147"/>
        <source>Show tab texts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="159"/>
        <source>Prefer icons from theme over ForkAwesome icons (needs restart to apply)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="168"/>
        <source>Icons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plasmoid::Settings</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="29"/>
        <source>The settings on this page are specific to the current instance of the Plasmoid.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plasmoid::SettingsDialog</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="128"/>
        <source>Plasmoid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="136"/>
        <source>General web view settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="138"/>
        <source>Built-in web view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="144"/>
        <source>Extras</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plasmoid::ShortcutOptionPage</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="66"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="72"/>
        <source>Global shortcut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plasmoid::SyncthingApplet</name>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="455"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="467"/>
        <source>New notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="536"/>
        <source>Unable to establish connection to Syncthing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="604"/>
        <source>D-Bus error - unable to </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecentChangesPage</name>
    <message>
        <location filename="../package/contents/ui/RecentChangesPage.qml" line="109"/>
        <source>Copy path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/RecentChangesPage.qml" line="114"/>
        <source>Copy device ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/RecentChangesPage.qml" line="119"/>
        <source>Copy directory ID</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatisticsView</name>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="12"/>
        <source> files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="17"/>
        <source> directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="23"/>
        <source> size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToolBar</name>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="25"/>
        <source>Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="41"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="50"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="99"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="113"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="169"/>
        <source>Show new notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="188"/>
        <source>About Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="200"/>
        <source>Show own device ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="216"/>
        <source>Show Syncthing log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="228"/>
        <source>Rescan all directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="244"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="259"/>
        <source>Open Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../package/contents/ui/main.qml" line="59"/>
        <source>Open Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="60"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="61"/>
        <source>Rescan all directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="63"/>
        <source>Show own device ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="65"/>
        <source>Restart Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="67"/>
        <source>Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="68"/>
        <source>Internal errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="70"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
